@@ -45,13 +45,25 @@ class APaymentDataSplit(BaseModel):
         validate_assignment = True
 
 
+class APaymentDataStamp(BaseModel):
+    amount: Optional[float]
+    collection_data: Optional[str]
+    reason: str
+
+    class Config:
+        validate_all = True
+        validate_assignment = True
+
+
 class APaymentData(BaseModel):
     reason: str
     amount: float
     expire_at: str
     split: Union[List[Optional[APaymentDataSplit]], Dict[str, Optional[float]], None]
+    stamps: Union[List[Optional[APaymentDataStamp]], Dict[str, Optional[float]], None]
     notify: ANotify
     landing: Landing
+    config_id: UUID
 
     class Config:
         validate_all = True
@@ -90,7 +102,6 @@ class Application(BaseModel):
     created_at: str
     payment_data: APaymentData
     applicant: Applicant = Field(alias='data')
-    locale: str = None
     event_version: str
     event_id: UUID
 
