@@ -30,9 +30,6 @@ def check_isoformat_none_case(v: Optional[str]):
 class HttpMethodType(Enum):
     HTTP_METHOD_GET = 'GET'
     HTTP_METHOD_POST = 'POST'
-    HTTP_METHOD_PUT = 'PUT'
-    HTTP_METHOD_PATCH = 'PATCH'
-    HTTP_METHOD_DELETE = 'DELETE'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -55,7 +52,6 @@ class PaymentStatus(Enum):
     STATUS_NOTIFICATION_PENDING = 'NOTIFICATION_PENDING'
     STATUS_COMPLETE = 'COMPLETE'
     STATUS_EXPIRED = 'EXPIRED'
-    STATUS_CANCELED = 'CANCELED'
 
     def json(self):
         return json.dumps(self, cls=PaymentEncoder)
@@ -68,6 +64,18 @@ class PaymentType(Enum):
         return json.dumps(self, cls=PaymentEncoder)
 
 
+class RemoteCollectionType(BaseModel):
+    id: UUID
+    type: str
+
+    class Config:
+        validate_all = True
+        validate_assignment = True
+
+    def json(self):
+        return json.dumps(self, cls=PaymentEncoder)
+
+
 class PayerType(Enum):
     TYPE_HUMAN = 'human'
     TYPE_LEGAL = 'legal'
@@ -89,6 +97,20 @@ class PaymentDataSplit(BaseModel):
         return json.dumps(self, cls=PaymentEncoder)
 
 
+class PaymentDataStamp(BaseModel):
+    amount: float
+    collection_data: Optional[str]
+    reason: str
+    meta: dict
+
+    class Config:
+        validate_all = True
+        validate_assignment = True
+
+    def json(self):
+        return json.dumps(self, cls=PaymentEncoder)
+
+
 class PaymentData(BaseModel):
     transaction_id: Optional[str]
     paid_at: Optional[str]
@@ -99,6 +121,7 @@ class PaymentData(BaseModel):
     iud: str
     iuv: Optional[str]
     split: List[Optional[PaymentDataSplit]]
+    stamps: List[Optional[PaymentDataStamp]]
 
     class Config:
         validate_all = True
@@ -138,14 +161,6 @@ class Receipt(OnlinePaymentBegin):
     pass
 
 
-class Confirm(OnlinePaymentBegin):
-    pass
-
-
-class Cancel(OnlinePaymentBegin):
-    pass
-
-
 class Notify(BaseModel):
     url: Optional[str]
     method: Optional[HttpMethodType]
@@ -185,8 +200,6 @@ class Links(BaseModel):
     receipt: Receipt
     notify: Optional[List[Notify]]
     update: Update
-    confirm: Confirm = Confirm(**{'url': None, 'last_opened_at': None, 'method': None})
-    cancel: Cancel = Cancel(**{'url': None, 'last_opened_at': None, 'method': None})
 
     class Config:
         validate_all = True
@@ -232,7 +245,7 @@ class Payment(BaseModel):
     user_id: UUID
     type: PaymentType
     tenant_id: UUID
-    service_id: UUID
+    remote_collection: RemoteCollectionType
     created_at: str
     updated_at: str
     status: PaymentStatus
@@ -241,7 +254,6 @@ class Payment(BaseModel):
     payment: PaymentData
     links: Links
     payer: Payer
-    locale: str = None
     event_id: UUID
     event_version: str
     event_created_at: str
