@@ -56,6 +56,18 @@ def get_application_data(
             'amount': '10',
             'expire_at': '2022-04-28T11:18:41+02:00',
             'split': [{'code': '2020/1', 'amount': '8', 'meta': {}}, {'code': '2020/2', 'amount': '2', 'meta': {}}],
+            'stamps': [
+                {
+                    'amount': '16',
+                    'collection_data': '9/123',
+                    'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+                },
+                {
+                    'amount': '16',
+                    'collection_data': '9/123',
+                    'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+                },
+            ],
             'notify': {
                 'url': 'https://www2.stanzadelcittadino.it'
                 '/comune-di-bugliano/api/applications/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/payment',
@@ -66,6 +78,7 @@ def get_application_data(
                 '/comune-di-bugliano/pratiche/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/detail',
                 'method': 'GET',
             },
+            'config_id': 'cf9ece67-1956-49c9-af89-a19120485fef',
         },
         'status': '1500',
         'status_name': 'status_payment_pending',
@@ -85,7 +98,6 @@ def get_application_data(
         'integrations': [],
         'backoffice_data': None,
         'flow_changed_at': '2022-04-28T11:18:41+02:00',
-        'locale': 'IT',
         'event_version': '2.0',
         'event_id': 'bb7044e4-066c-4bf7-915e-87ee97270eae',
         **kwargs,
@@ -108,6 +120,18 @@ def get_application_payment_data(**kwargs):
         'amount': '10',
         'expire_at': '2022-04-28T11:18:41+02:00',
         'split': [{'code': '2020/1', 'amount': '8', 'meta': {}}, {'code': '2020/2', 'amount': '2', 'meta': {}}],
+        'stamps': [
+            {
+                'amount': '16',
+                'collection_data': '9/123',
+                'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+            },
+            {
+                'amount': '16',
+                'collection_data': '9/123',
+                'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+            },
+        ],
         'notify': {
             'url': 'https://www2.stanzadelcittadino.it'
             '/comune-di-bugliano/api/applications/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/payment',
@@ -118,6 +142,7 @@ def get_application_payment_data(**kwargs):
             '/comune-di-bugliano/pratiche/3c819c1d-6587-448d-8ba4-3b6f23e87ed4/detail',
             'method': 'GET',
         },
+        'config_id': 'cf9ece67-1956-49c9-af89-a19120485fef',
         **kwargs,
     }
 
@@ -128,7 +153,10 @@ def get_payment_event_data(**kwargs):
         'user_id': '43f619df-3ba2-4d9d-bcdd-270484eac44d',
         'type': 'PAGOPA',
         'tenant_id': '2eeb8374-c8f9-4260-9e94-22504e262eb1',
-        'service_id': 'cf9ece67-1956-49c9-af89-a19120485fef',
+        'remote_collection': {
+            'id': 'cf9ece67-1956-49c9-af89-a19120485fef',
+            'type': 'application',
+        },
         'created_at': '2022-06-08T08:28:42+00:00',
         'updated_at': '2022-06-08T10:29:39+02:00',
         'status': 'CREATION_PENDING',
@@ -144,6 +172,7 @@ def get_payment_event_data(**kwargs):
             'iud': 'bb7044e4066c4bf7915e87ee97270eae',
             'iuv': None,
             'split': [],
+            'stamps': [],
         },
         'links': {
             'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
@@ -164,8 +193,6 @@ def get_payment_event_data(**kwargs):
                 },
             ],
             'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
-            'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
-            'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
         },
         'payer': {
             'type': 'human',
@@ -180,7 +207,6 @@ def get_payment_event_data(**kwargs):
             'country': 'IT',
             'email': 'raffaele.luccisano@opencontent.it',
         },
-        'locale': 'IT',
         'event_id': 'c5cebc1a-5d6f-4921-bc15-ff0575ea6f75',
         'event_version': '2.0',
         'event_created_at': '2022-06-08T08:28:42+00:00',
@@ -200,6 +226,7 @@ def get_payment_data(**kwargs):
         'iud': 'bb7044e4066c4bf7915e87ee97270eae',
         'iuv': None,
         'split': [],
+        'stamps': [],
         **kwargs,
     }
 
@@ -248,6 +275,33 @@ def get_split_data_complete():
     ]
 
 
+def get_stamps_data(**kwargs):
+    return {
+        'amount': 16,
+        'collection_data': '9/123',
+        'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+        'meta': {},
+        **kwargs,
+    }
+
+
+def get_stamps_data_complete():
+    return [
+        {
+            'amount': '16.00',
+            'collection_data': '9/123',
+            'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+            'meta': {},
+        },
+        {
+            'amount': '16.00',
+            'collection_data': '9/123',
+            'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+            'meta': {},
+        },
+    ]
+
+
 def get_payer_data(**kwargs):
     return {
         'type': 'human',
@@ -266,32 +320,6 @@ def get_payer_data(**kwargs):
 
 
 def get_links_data(**kwargs):
-    return {
-        'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
-        'online_payment_landing': {
-            'url': 'https://devsdc.opencontent.it/'
-            'comune-di-bugliano/it/pratiche/a51cc065-4fb1-4ace-8d3f-e3a70c867472/detail',
-            'last_opened_at': None,
-            'method': 'GET',
-        },
-        'offline_payment': {'url': None, 'last_opened_at': None, 'method': 'GET'},
-        'receipt': {'url': None, 'last_opened_at': None, 'method': 'GET'},
-        'notify': [
-            {
-                'url': 'https://devsdc.opencontent.it/'
-                'comune-di-bugliano/api/applications/a51cc065-4fb1-4ace-8d3f-e3a70c867472/payment',
-                'method': 'POST',
-                'sent_at': None,
-            },
-        ],
-        'update': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'GET'},
-        'confirm': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
-        'cancel': {'url': None, 'last_check_at': None, 'next_check_at': None, 'method': 'PATCH'},
-        **kwargs,
-    }
-
-
-def get_links_data_without_cancel_and_confirm(**kwargs):
     return {
         'online_payment_begin': {'url': None, 'last_opened_at': None, 'method': 'GET'},
         'online_payment_landing': {
