@@ -17,6 +17,7 @@ from oc_python_sdk.models.payment import (
     Payment,
     PaymentData,
     PaymentDataSplit,
+    PaymentDataStamp,
     PaymentStatus,
     PaymentType,
     Update,
@@ -25,7 +26,6 @@ from oc_python_sdk.models.payment import (
 from ._helpers import (
     get_empty_notify_data,
     get_links_data,
-    get_links_data_without_cancel_and_confirm,
     get_notify_data,
     get_online_payment_begin_data,
     get_payer_data,
@@ -34,6 +34,8 @@ from ._helpers import (
     get_split_data,
     get_split_data_complete,
     get_split_data_invalid,
+    get_stamps_data,
+    get_stamps_data_complete,
     get_update_data,
 )
 
@@ -130,6 +132,7 @@ class PaymentTestCase(TestCase):
     def test_encoders(self):
         payment = Payment(**get_payment_event_data())
         empty_split = payment.payment.split
+        empty_stamps = payment.payment.stamps
 
         payment_empty_notify = Payment(**get_payment_event_data())
         payment_empty_notify.links.notify = None
@@ -138,18 +141,23 @@ class PaymentTestCase(TestCase):
         payment_data_with_split.split = get_split_data_complete()
         payment_with_split = Payment(**get_payment_event_data(payment=payment_data_with_split))
 
+        payment_data_with_stamps = payment.payment
+        payment_data_with_stamps.stamps = get_stamps_data_complete()
+        payment_with_stamps = Payment(**get_payment_event_data(payment=payment_data_with_stamps))
+
         payment_data = PaymentData(**get_payment_data())
         split = PaymentDataSplit(**get_split_data())
+        stamps = PaymentDataStamp(**get_stamps_data())
         online_payment_begin = OnlinePaymentBegin(**get_online_payment_begin_data())
         notify = Notify(**get_notify_data())
         notify_no_data = Notify(**get_empty_notify_data())
         update = Update(**get_update_data())
         links = Links(**get_links_data())
-        links_without_cancel_and_confirm = Links(**get_links_data_without_cancel_and_confirm())
         payer = Payer(**get_payer_data())
 
         self.assertEqual(json.loads(payment.json())['id'], 'bb7044e4-066c-4bf7-915e-87ee97270eae')
         self.assertEqual(empty_split, [])
+        self.assertEqual(empty_stamps, [])
         self.assertEqual(
             json.loads(payment_with_split.json())['payment']['split'],
             [
@@ -177,6 +185,23 @@ class PaymentTestCase(TestCase):
                 },
             ],
         )
+        self.assertEqual(
+            json.loads(payment_with_stamps.json())['payment']['stamps'],
+            [
+                {
+                    'amount': 16.0,
+                    'collection_data': '9/123',
+                    'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+                    'meta': {},
+                },
+                {
+                    'amount': 16.0,
+                    'collection_data': '9/123',
+                    'reason': 'a51cc065-4fb1-4ace-8d3f-e3a70c867472 - SLVLNZ76P01g843v',
+                    'meta': {},
+                },
+            ],
+        )
         self.assertEqual(json.loads(payment.json())['created_at'], '2022-06-08T08:28:42+00:00')
         self.assertEqual(json.loads(payment.status.json()), PaymentStatus.STATUS_CREATION_PENDING.value)
         self.assertEqual(json.loads(payment.type.json()), PaymentType.TYPE_PAGOPA.value)
@@ -185,6 +210,7 @@ class PaymentTestCase(TestCase):
         self.assertEqual(json.loads(payment.links.notify[0].method.json()), HttpMethodType.HTTP_METHOD_POST.value)
         self.assertEqual(json.loads(payment_empty_notify.json())['links']['notify'], None)
         self.assertEqual(json.loads(split.json())['code'], 'CODE')
+        self.assertEqual(json.loads(stamps.json())['collection_data'], '9/123')
         self.assertEqual(json.loads(payment_data.json())['amount'], 1)
         self.assertEqual(json.loads(online_payment_begin.json())['url'], None)
         self.assertEqual(
@@ -196,10 +222,6 @@ class PaymentTestCase(TestCase):
         self.assertEqual(json.loads(notify_no_data.json()), {'url': None, 'method': None, 'sent_at': None})
         self.assertEqual(json.loads(update.json())['url'], None)
         self.assertEqual(len(json.loads(links.json())['notify']), 1)
-        self.assertEqual(
-            json.loads(links_without_cancel_and_confirm.json())['cancel'],
-            {'url': None, 'method': None, 'last_opened_at': None},
-        )
         self.assertEqual(json.loads(payer.json())['type'], PayerType.TYPE_HUMAN.value)
         with self.assertRaises(ValidationError):
             PaymentData(**get_payment_data(split=None))
